+++
title = "Publish date set using Hugo-compatible date string"
publishDate = 2018-01-23
tags = ["dates", "publishdate"]
draft = false
+++

The `publishdate` for this post is Hugo-compatible
i.e. [RFC3339-compliant](https://tools.ietf.org/html/rfc3339#section-5.8).
